<?php
/*
+--------------------------------------------------------------------------+
|   RevokeBB 1.0											               |
|   ========================================                               | 
|   author: denadai2 <denadai2@gmail.com>                                  |
|   copyright (c) 2006 RevokeSoft                                          |
|   http://www.revokesoft.net 											   |
|   license: http://opensource.org/licenses/gpl-license.php 			   |
|   GNU Public License                                					   |
|   ========================================							   |
+--------------------------------------------------------------------------+


*/

if ( ! defined( 'IN_REVOKE' ) )
{
	print '<html><head><title>RevokeBB Error</title></head><body><h1>Incorrect access</h1>You cannot access this file directly.</body></html>';
	exit();
}


class Status
	{
	/**
    * language class
    * @access Private
    * @var class
    */
	var $lang;
	
	/**
    * skin class
    * @access Private
    * @var class
    */
	var $skin;
	
	/**
    * info of the user
    * @access Public
    * @var array()
    */
	var $info_user;

	/**
    * Status constructor
    *
    * @param class $lang, class $skin
    * @author denadai2 <denadai2@gmail.com>
    * @since v 0.1
    * @access Public
    * @return none
    */	
	function Status(& $lang, & $skin, & $config)
	{ 
		$this->lang = & $lang;
		$this->skin = & $skin;
		$this->_config = & $config;
	}

	/**
    * Simple error view
    *
    * @param string $error_string
    * @author denadai2 <denadai2@gmail.com>
    * @since v 0.1
    * @access Public
    * @return none
    */		
	function simple_error($error_string)
	{
		$this->lang->load_file('errors');
		
		$this->skin->assign('user', $this->info_user);
		$this->skin->assign('text', $this->lang->language[$error_string]);
		$this->skin->assign('config', $this->classes->_config);
		$this->skin->assign('mode', array('modcp' => intval($_SESSION['modcp']), 'admin' => intval($this->info_user['admincp'] == 1)));
		$this->skin->assign('lang', $this->lang->lang_all);
		$this->skin->assign('act', 'error.tpl');
		
		$this->skin->cache = false;
		
		echo $this->skin->fetch('header.tpl'). $this->skin->fetch('main.tpl') . $this->skin->fetch('footer.tpl');
		exit;
	}

	/**
    * Complete message view
    *
    * @param string $url, String $text
    * @author denadai2 <denadai2@gmail.com>
    * @since v 0.1
    * @access Public
    * @return none
    */		
	function complete($url, $text)
	{
		$complete['url'] = $url;
		$complete['text'] = $text;
		
		$this->skin->assign('complete', $complete);
		$this->skin->assign('config', $this->classes->_config);
		$this->skin->assign('mode', array('modcp' => intval($_SESSION['modcp']), 'admin' => intval($this->info_user['admincp'] == 1)));
		$this->skin->assign('lang', $this->lang->lang_all);
		
		$this->skin->cache = false;
		
		echo $this->skin->fetch('complete.tpl');
		exit;
	}	
		
	/**
    * Login error view
    *
    * @param string $error_string
    * @author denadai2 <denadai2@gmail.com>
    * @since v 0.1
    * @access Public
    * @return none
    */		
	function login_error($error_string)
	{
		//if is logged
		if($this->info_user['user_id'] > 0)
			$this->simple_error($error_string);
			
		$this->lang->load_file('errors');
		
		$this->skin->assign('user', $this->info_user);
		$this->skin->assign('text', $this->lang->language[$error_string]);
		$this->skin->assign('config', $this->classes->_config);
		$this->skin->assign('mode', array('modcp' => intval($_SESSION['modcp']), 'admin' => intval($this->info_user['admincp'] == 1)));
		$this->skin->assign('lang', $this->lang->lang_all);
		$this->skin->assign('lang2', $this->lang->language);
		$this->skin->assign('act', 'login_error.tpl');

		$this->skin->cache = false;
		
		echo $this->skin->fetch('header.tpl'). $this->skin->fetch('main.tpl') . $this->skin->fetch('footer.tpl');
		exit;
	}

	/**
    * Fatal error
    *
    * @param string $error_string
    * @author denadai2 <denadai2@gmail.com>
    * @since v 0.1
    * @access Public
    * @return none
    */		
	function fatal_error($error_string)
	{
		echo '<html><head><title>RevokeBB Fatal error</title></head><body><div align="center"><p>&nbsp;</p><h3>Error!</h3>
<p>&nbsp;</p>
<div style="font-size:12px; font-family:verdana; width:500px; padding: 2px; color: #F40000; margin: 2px; background-color: #FFC4C4; border: 1px solid #F40000;">'.$error_string.'</div></div></body></html>';
		exit;
	}
	
	function admin_complete($string, $url)
	{
		
		$this->skin->assign('text', $string);
		$this->skin->assign('url', $url);
		$this->skin->assign('config', $this->classes->_config);
		$this->skin->assign('mode', array('admin' => intval($this->classes->user->info_user['admincp'] == 1)));
		$this->skin->assign('lang', $this->lang->lang_all);
		
		
		$this->skin->display('admincp/ad_complete.tpl');
		exit;
	}
	
	function admin_error($string, $url)
	{
		$this->lang->load_file('errors');
		
		
		$this->skin->assign('text', $this->lang->language[$string]);
		$this->skin->assign('url', $url);
		$this->skin->assign('config', $this->classes->_config);
		$this->skin->assign('mode', array('admin' => intval($this->classes->user->info_user['admincp'] == 1)));
		$this->skin->assign('lang', $this->lang->lang_all);
		
		
		$this->skin->display('admincp/ad_error.tpl');
		exit;
	}	
	
	/**
    * Confirm form view
    *
    * @param string $error_string
    * @author denadai2 <denadai2@gmail.com>
    * @since v 0.1
    * @access Public
    * @return none
    */		
	function confirm($string, $url)
	{
		$this->lang->load_file('errors');
		
		$this->skin->assign('user', $this->info_user);
		$this->skin->assign('text', $string);
		$this->skin->assign('formaction', $url);
		$this->skin->assign('config', $this->classes->_config);
		$this->skin->assign('mode', array('modcp' => intval($_SESSION['modcp']), 'admin' => intval($this->info_user['admincp'] == 1)));
		$this->skin->assign('lang', $this->lang->lang_all);
		$this->skin->assign('act', 'question.tpl');
		
		$this->skin->cache = false;
		
		echo $this->skin->fetch('header.tpl'). $this->skin->fetch('main.tpl') . $this->skin->fetch('footer.tpl');
		exit;
	}
	
	/**
    * Confirm form view with html
    *
    * @param string $error_string
    * @author denadai2 <denadai2@gmail.com>
    * @since v 0.1
    * @access Public
    * @return none
    */		
	function confirm2($string, $url)
	{
		$this->lang->load_file('errors');
		
		$this->skin->assign('user', $this->info_user);
		$this->skin->assign('text', $string);
		$this->skin->assign('formaction', $url);
		$this->skin->assign('config', $this->classes->_config);
		$this->skin->assign('mode', array('modcp' => intval($_SESSION['modcp']), 'admin' => intval($this->info_user['admincp'] == 1)));
		$this->skin->assign('lang', $this->lang->lang_all);
		$this->skin->assign('act', 'confirm.tpl');
		
		$this->skin->cache = false;
		
		echo $this->skin->fetch('header.tpl'). $this->skin->fetch('main.tpl') . $this->skin->fetch('footer.tpl');
		exit;
	}

	}
	?>