<?php
define('GzOutput_ACCEPT_ENCODING', isset($_SERVER['HTTP_ACCEPT_ENCODING']));
define('GzOutput_GZIP', GzOutput_ACCEPT_ENCODING && strpos($_SERVER['HTTP_ACCEPT_ENCODING'], 'gzip') !== false);
define('GzOutput_DEFLATE', GzOutput_ACCEPT_ENCODING && strpos($_SERVER['HTTP_ACCEPT_ENCODING'], 'deflate') !== false);

/**
 * GzOutput class,
 *	simple class with some static method to create gz output without ob_gzhandler
 * ______________________________________________________________
 * @example
 * 	GzOutput::create('body{padding:0;}', 'text/css');			// css file
 *      	GzOutput::createNew('var something = "somevalue";', 'text/javascript');	// JS file without caching
 * 	GzOutput::createFromList(array('file.css', 'file2.css'), 'text/css');	// css file
 *	GzOutput::createNewFromList(array('file.css', 'file2.css'), 'text/css');	// css file without caching
 * --------------------------------------------------------------
 * @Compatibility	PHP >= 4
 * @Author		Andrea Giammarchi
 * @Site		http://www.devpro.it/
 * @Date		2006/12/17
 * @Version		0.2 [better cache managment for both gzip compatible and uncompatible browsers]
 */
class GzOutput {

	/**
	 * public static method,
	 *	exit showing created output using a compression level
	 *
	 *	GzOutput::create(output:String, type:String [, level:UIntRange(0,9)]):Void(exit)
	 *
	 * @param	String		the content to show
	 * @param	String		the Content-Type (i.e. "text/css", "text/javascript", "text/html; charset:UTF-8")
	 * @param	UInt		compression level from 0 to 9, default 9
	 */
	function create($output, $type, $level = 9) {
	
	//denadai2 mod:
		// init ob handler
		ob_start("ob_gzhandler");
			
				// flush output buffer
		
		
		exit($output);
		
	}

	/**
	 * public static method,
	 *	exit showing created output using a compression level and removing cache problems
	 *
	 *	GzOutput::createNew(output:String, type:String [, level:UIntRange(0,9)]):Void(exit)
	 *
	 * @param	String		the content to show
	 * @param	String		the Content-Type (i.e. "text/css", "text/javascript", "text/html; charset:UTF-8")
	 * @param	UInt		compression level from 0 to 9, default 9
	 */
	function createNew($output, $type, $level = 9) {
		define('GzOutput_NO_CACHE', true);
		header('Expires: Mon, 26 Jul 1997 05:00:00 GMT');
		header('Last-Modified: '.gmdate('D, d M Y H:i:s').' GMT');
		header('Cache-Control: no-store, no-cache, must-revalidate');
		header('Cache-Control: post-check=0, pre-check=0', false);
		header('Pragma: no-cache');
		GzOutput::create($output, $type, $level);
	}

	/**
	 * public static method,
	 *	exit showing created output using an array with file names to read
	 *
	 *	GzOutput::createFromList(list:Array, type:String [, level:UIntRange(0,9)]):Void(exit)
	 *
	 * @param	Array		an array with one or more files to get contents to create the output
	 * @param	String		the Content-Type (i.e. "text/css", "text/javascript", "text/html; charset:UTF-8")
	 * @param	UInt		compression level from 0 to 9, default 9
	 */
	function createFromList($list, $type, $level = 9) {
		GzOutput::__listToOutput($list, $type, $level, false);
        }

	/**
	 * public static method,
	 *	exit showing created output using an array with file names to read and removing cache problems
	 *
	 *	GzOutput::createNewFromList(list:Array, type:String [, level:UIntRange(0,9)]):Void(exit)
	 *
	 * @param	Array		an array with one or more files to get contents to create the output
	 * @param	String		the Content-Type (i.e. "text/css", "text/javascript", "text/html; charset:UTF-8")
	 * @param	UInt		compression level from 0 to 9, default 9
	 */
	function createNewFromList($list, $type, $level = 9) {
		GzOutput::__listToOutput($list, $type, $level, true);
        }

	/**
	 * private static method,
	 *	creates an output looping over list array and reading each file content.
	 *
	 *	GzOutput::__listToOutput(*list:Array, *type:String, *level:UIntRange(0,9) [, nocache:Boolean]):Void(exit)
	 *
	 * @param	Array		an array with one or more files to get contents to create the output
	 * @param	String		the Content-Type (i.e. "text/css", "text/javascript", "text/html; charset:UTF-8")
	 * @param	UInt		compression level from 0 to 9, default 9
	 * @param	Boolean		doesn't use cache or use it if present
	 */
	function __listToOutput(&$list, &$type, &$level, $new) {
		$create = $new ? 'createNew' : 'create';
		for($i = 0, $j = count($list); $i < $j; $i++)
			$list[$i] = file_exists($list[$i]) ? file_get_contents($list[$i]) : '';
			
		GzOutput::$create(implode("\r\n", $list), $type, $level);
	}
}


function gzdecode($data) {
  $len = strlen($data);
  if ($len < 18 || strcmp(substr($data,0,2),"\x1f\x8b")) {
   return null;  // Not GZIP format (See RFC 1952)
  }
  $method = ord(substr($data,2,1));  // Compression method
  $flags  = ord(substr($data,3,1));  // Flags
  if ($flags & 31 != $flags) {
   // Reserved bits are set -- NOT ALLOWED by RFC 1952
   return null;
  }
  // NOTE: $mtime may be negative (PHP integer limitations)
  $mtime = unpack("V", substr($data,4,4));
  $mtime = $mtime[1];
  $xfl  = substr($data,8,1);
  $os    = substr($data,8,1);
  $headerlen = 10;
  $extralen  = 0;
  $extra    = "";
  if ($flags & 4) {
   // 2-byte length prefixed EXTRA data in header
   if ($len - $headerlen - 2 < 8) {
     return false;    // Invalid format
   }
   $extralen = unpack("v",substr($data,8,2));
   $extralen = $extralen[1];
   if ($len - $headerlen - 2 - $extralen < 8) {
     return false;    // Invalid format
   }
   $extra = substr($data,10,$extralen);
   $headerlen += 2 + $extralen;
  }

  $filenamelen = 0;
  $filename = "";
  if ($flags & 8) {
   // C-style string file NAME data in header
   if ($len - $headerlen - 1 < 8) {
     return false;    // Invalid format
   }
   $filenamelen = strpos(substr($data,8+$extralen),chr(0));
   if ($filenamelen === false || $len - $headerlen - $filenamelen - 1 < 8) {
     return false;    // Invalid format
   }
   $filename = substr($data,$headerlen,$filenamelen);
   $headerlen += $filenamelen + 1;
  }

  $commentlen = 0;
  $comment = "";
  if ($flags & 16) {
   // C-style string COMMENT data in header
   if ($len - $headerlen - 1 < 8) {
     return false;    // Invalid format
   }
   $commentlen = strpos(substr($data,8+$extralen+$filenamelen),chr(0));
   if ($commentlen === false || $len - $headerlen - $commentlen - 1 < 8) {
     return false;    // Invalid header format
   }
   $comment = substr($data,$headerlen,$commentlen);
   $headerlen += $commentlen + 1;
  }

  $headercrc = "";
  if ($flags & 1) {
   // 2-bytes (lowest order) of CRC32 on header present
   if ($len - $headerlen - 2 < 8) {
     return false;    // Invalid format
   }
   $calccrc = crc32(substr($data,0,$headerlen)) & 0xffff;
   $headercrc = unpack("v", substr($data,$headerlen,2));
   $headercrc = $headercrc[1];
   if ($headercrc != $calccrc) {
     return false;    // Bad header CRC
   }
   $headerlen += 2;
  }

  // GZIP FOOTER - These be negative due to PHP's limitations
  $datacrc = unpack("V",substr($data,-8,4));
  $datacrc = $datacrc[1];
  $isize = unpack("V",substr($data,-4));
  $isize = $isize[1];

  // Perform the decompression:
  $bodylen = $len-$headerlen-8;
  if ($bodylen < 1) {
   // This should never happen - IMPLEMENTATION BUG!
   return null;
  }
  $body = substr($data,$headerlen,$bodylen);
  $data = "";
  if ($bodylen > 0) {
   switch ($method) {
     case 8:
       // Currently the only supported compression method:
       $data = gzinflate($body);
       break;
     default:
       // Unknown compression method
       return false;
   }
  } else {
   // I'm not sure if zero-byte body content is allowed.
   // Allow it for now...  Do nothing...
  }

  // Verifiy decompressed size and CRC32:
  // NOTE: This may fail with large data sizes depending on how
  //      PHP's integer limitations affect strlen() since $isize
  //      may be negative for large sizes.
  if ($isize != strlen($data) || crc32($data) != $datacrc) {
   // Bad format!  Length or CRC doesn't match!
   return false;
  }
  return $data;
}

?>